@@ -1,6 +1,7 @@
 package openshiftapiserver
 
 import (
+	"context"
 	"encoding/json"
 	"fmt"
 	"net/http"
@@ -31,7 +32,6 @@ import (
 	openshiftcontrolplanev1 "github.com/openshift/api/openshiftcontrolplane/v1"
 	operatorinformers "github.com/openshift/client-go/operator/informers/externalversions"
 	quotainformer "github.com/openshift/client-go/quota/informers/externalversions"
-	securityv1client "github.com/openshift/client-go/security/clientset/versioned/typed/security/v1"
 	securityv1informer "github.com/openshift/client-go/security/informers/externalversions"
 	"github.com/openshift/library-go/pkg/quota/clusterquotamapping"
 	oappsapiserver "github.com/openshift/openshift-apiserver/pkg/apps/apiserver"
@@ -466,7 +466,6 @@ func (c completedConfig) New(delegationTarget genericapiserver.DelegationTarget)
 	s.GenericAPIServer.AddPostStartHookOrDie("authorization.openshift.io-ensureopenshift-infra", c.EnsureOpenShiftInfraNamespace)
 	s.GenericAPIServer.AddPostStartHookOrDie("project.openshift.io-projectcache", c.startProjectCache)
 	s.GenericAPIServer.AddPostStartHookOrDie("project.openshift.io-projectauthorizationcache", c.startProjectAuthorizationCache)
-	s.GenericAPIServer.AddPostStartHookOrDie("security.openshift.io-bootstrapscc", c.bootstrapSCC)
 	s.GenericAPIServer.AddPostStartHookOrDie("openshift.io-startinformers", func(context genericapiserver.PostStartHookContext) error {
 		c.ExtraConfig.InformerStart(context.StopCh)
 		return nil
@@ -544,53 +543,8 @@ func (c *completedConfig) startProjectAuthorizationCache(context genericapiserve
 	return nil
 }
 
-func (c *completedConfig) bootstrapSCC(context genericapiserver.PostStartHookContext) error {
-	ns := bootstrappolicy.DefaultOpenShiftInfraNamespace
-	bootstrapSCCGroups, bootstrapSCCUsers := bootstrappolicy.GetBoostrapSCCAccess(ns)
-
-	// SCC is served using CRD resource any status update must use JSON
-	jsonLoopbackClientConfig := rest.CopyConfig(c.ExtraConfig.KubeAPIServerClientConfig)
-	jsonLoopbackClientConfig.ContentConfig.AcceptContentTypes = "application/json"
-	jsonLoopbackClientConfig.ContentConfig.ContentType = "application/json"
-	securityClient, err := securityv1client.NewForConfig(jsonLoopbackClientConfig)
-	if err != nil {
-		utilruntime.HandleError(fmt.Errorf("error getting client: %v", err))
-		return err
-	}
-
-	// all SCC must exist before we report success
-	err = wait.PollUntil(1*time.Second, func() (bool, error) {
-		anySCCMissing := false
-		for _, scc := range bootstrappolicy.GetBootstrapSecurityContextConstraints(bootstrapSCCGroups, bootstrapSCCUsers) {
-			_, err := securityClient.SecurityContextConstraints().Create(scc)
-			if err == nil {
-				klog.Infof("Created default security context constraint %s", scc.Name)
-				continue
-			}
-			if kapierror.IsAlreadyExists(err) {
-				klog.V(4).Infof("default security context constraint %s, already exists", scc.Name)
-				continue
-			}
-			anySCCMissing = true
-			utilruntime.HandleError(fmt.Errorf("unable to create default security context constraint %s; %v", scc.Name, err))
-			continue
-		}
-		if anySCCMissing {
-			return false, nil
-		}
-
-		return true, nil
-	}, context.StopCh)
-	if err != nil {
-		utilruntime.HandleError(fmt.Errorf("error creating SCC: %v", err))
-		return err
-	}
-
-	return nil
-}
-
 // EnsureOpenShiftInfraNamespace is called as part of global policy initialization to ensure infra namespace exists
-func (c *completedConfig) EnsureOpenShiftInfraNamespace(context genericapiserver.PostStartHookContext) error {
+func (c *completedConfig) EnsureOpenShiftInfraNamespace(_ genericapiserver.PostStartHookContext) error {
 	namespaceName := bootstrappolicy.DefaultOpenShiftInfraNamespace
 
 	var coreClient *corev1client.CoreV1Client
@@ -608,14 +562,14 @@ func (c *completedConfig) EnsureOpenShiftInfraNamespace(context genericapiserver
 		return err
 	}
 
-	_, err = coreClient.Namespaces().Create(&corev1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: namespaceName}})
+	_, err = coreClient.Namespaces().Create(context.TODO(), &corev1.Namespace{ObjectMeta: metav1.ObjectMeta{Name: namespaceName}}, metav1.CreateOptions{})
 	if err != nil && !kapierror.IsAlreadyExists(err) {
 		utilruntime.HandleError(fmt.Errorf("error creating namespace %q: %v", namespaceName, err))
 		return err
 	}
 
 	// Ensure we have the bootstrap SA for Nodes
-	_, err = coreClient.ServiceAccounts(namespaceName).Create(&corev1.ServiceAccount{ObjectMeta: metav1.ObjectMeta{Name: bootstrappolicy.InfraNodeBootstrapServiceAccountName}})
+	_, err = coreClient.ServiceAccounts(namespaceName).Create(context.TODO(), &corev1.ServiceAccount{ObjectMeta: metav1.ObjectMeta{Name: bootstrappolicy.InfraNodeBootstrapServiceAccountName}}, metav1.CreateOptions{})
 	if err != nil && !kapierror.IsAlreadyExists(err) {
 		klog.Errorf("Error creating service account %s/%s: %v", namespaceName, bootstrappolicy.InfraNodeBootstrapServiceAccountName, err)
 	}
